<?php
/**
 * Plugin mailCommentAlert
 * Réalisé à partir du plugin plxMyComRememberMe de Stephane F
 * @author	bronco@warriordudimanche.net/Stephane F
 **/
class mailCommentAlert extends plxPlugin {

	private $db=array();
	/**
	 * Constructeur de la classe
	 *
	 * @param	default_lang	langue par défaut
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function __construct($default_lang) {

		# appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		$this->setConfigProfil(PROFIL_ADMIN);

		if (!defined('MAIL_AVAILABLE')){
			define('MAIL_AVAILABLE', plxUtils::testMail(false));
		}
		if(MAIL_AVAILABLE){
			$this->load();
		}

		# déclaration des hooks
		$this->addHook('plxMotorAddCommentaire', 'plxMotorAddCommentaire');
		$this->addHook('plxMotorConstruct', 'plxMotorConstruct');
		$this->addHook('IndexEnd', 'IndexEnd');
		$this->addHook('AdminCommentsPrepend', 'AdminCommentsPrepend');

	}

	/**
	 * Méthode qui ajoute la case à cocher "Etre averti par mail des commentaires" au niveau des commentaires
	 * et qui gère l'unsuscribe
	 * @return	stdio
	 * @author	Stephane F./Bronco
	 *
	 **/
	public function IndexEnd() {
		if(MAIL_AVAILABLE){
			echo '<?php 
			$text = "<label class=\"mailme\"><input type=\"checkbox\" id=\"id_mailme\" name=\"mailme\" value=\"1\" />&nbsp;'.$this->getLang('L_MAILME').'</label>";
			$output = preg_replace("/<textarea.+name=[\'\"]content[\'\"](.*?)<\/textarea>/i", "$0".$text, $output);
			?>';
		}
		$plxMotor=plxMotor::getInstance();
		$artId=$plxMotor->cible;
		if (!empty($_GET['unsuscribe'])&&!empty($artId)){
			$_GET['unsucribe']=strip_tags($_GET['unsuscribe']);
			$this->remove_email($artId,$_GET['unsuscribe']);
			exit('<h1><em>'.$_GET['unsuscribe'].'</em> '.$this->getLang('L_REMOVED').'</h1>');
		}
	}	

	/**
	 * Poste le mail quand le modérateur valide le commentaire
	 *
	 * @author	Bronco
	 *
	 **/
	public function AdminCommentsPrepend() {
		global $plxAdmin;
		$plxMotor=plxMotor::getInstance();
		
		if (empty($_POST['idCom'])||empty($_POST['selection'])||$_POST['selection']!='online'){return;}
		foreach($_POST['idCom'] as $commId){
			preg_match('#_(?P<artId>[0-9]*?)\.#',$commId,$r);
			$artId   =$r['artId'];
			$comData =$plxMotor->parseCommentaire(PLX_ROOT.$plxAdmin->aConf['racine_commentaires'].$commId.'.xml');
			$artData =$plxMotor->parseArticle(PLX_ROOT.$plxAdmin->aConf['racine_articles'].$plxMotor->plxGlob_arts->aFiles[$artId]);
			
			$content=$this->createContent(
				$artId,
				$artData['title'],
				$artData['url'],
				$comData['content'],
				$comData['author']
			);
			$subject=$plxMotor->aConf['title'].': '.$this->getLang('L_NEW_COMMENT_ABOUT').' «'.$artData['title'].'»';
			$content.='<hr/><a href="'.$plxMotor->aConf['racine'].$artData['url'].'">Article &#8605;</a> - <a href="'.$plxMotor->aConf['racine'].$artData['url'].'#'.$commId.'">Comm &#8605;</a> ';		
			if (!empty($this->db[$artId])){
				$emails=$this->db[$artId];
				foreach($emails as $email=>$name){		
					$content_temp=$content.'- <a href="'.$plxMotor->aConf['racine'].$artData['url'].'&unsuscribe='.$email.'&a='.$artId.'">'.$this->getLang('L_UNSUSCRIBE').' &#10006;</a>';
					plxUtils::sendMail($name, $plxMotor->aConf['title'], $email, $subject, str_replace('#DESTINATAIRE',$name,$content_temp), $contentType="html");
				}
			}
		}
		
		
	}

	/**
	 * Méthode qui ajoute le mail dans la base pour cet article
	 * et envoie le ou les mails 
	 * @return	stdio
	 * @author	Stephane F./Bronco
	 *
	 **/
	public function plxMotorAddCommentaire() {
		if(MAIL_AVAILABLE){
			$string = '
			//var_dump($_POST);exit;
				$this->plxPlugins->aPlugins["mailCommentAlert"]->mailNewComm(null,strip_tags($content["content"]),strip_tags($content["author"]),$content);
			if(isset($_POST["mailme"])){
				$this->plxPlugins->aPlugins["mailCommentAlert"]->add_email($this->plxRecord_arts->f("numero"),strip_tags($_POST["mail"]),strip_tags($_POST["name"]));
			}
			';
			echo "<?php ".$string." ?>";
		}
	}


	# load
	###########################
	public function load(){
		$file=PLX_PLUGINS.'mailCommentAlert/mail_db.php';
		$this->db = (file_exists($file) ? unserialize(gzinflate(base64_decode(substr(file_get_contents($file),9,-strlen(6))))) : array() );
		return $this->db;
	}

	# save
	###########################
	public function save(){
		$file=PLX_PLUGINS.'mailCommentAlert/mail_db.php';
		if (empty($this->db)){$data=array();}
		else{$data=$this->db;}
		return file_put_contents($file, '<?php /* '.base64_encode(gzdeflate(serialize($data))).' */ ?>');
	}

	# add email
	###########################
	public function add_email($artId=null,$email=null,$name=null){
		if (!$artId||!$email){return false;}
		if (!$name){$name=$email;}

		$this->db[$artId][$email]=$name;
		$this->save();
	}


	# remove email
	###########################
	public function remove_email($artId=null,$email=null){
		if (!$artId||!$email){return false;}
		if (isset($this->db[$artId][$email])){
			unset($this->db[$artId][$email]);
			$this->save();
			return true;
		}
		return false;
	}

	private function createContent($artId=null,$title=null,$url_art=null,$content=null,$name=null){
		$plxMotor=plxMotor::getInstance();

		# create content
		
		$subject=$plxMotor->aConf['title'].': '.$this->getLang('L_NEW_COMMENT_ABOUT').' «'.$title.'»';

		$content=
			$this->getLang('L_HELLO').' #DESTINATAIRE'
			.",<br/>"
			.'<strong>'.$name.'</strong>'
			.' '
			.$this->getLang('L_COMMENTED')
			.' <blockquote>'.$title.'</em>»: '
			."<br/><br/>«<em style='font-size:20px'>"
			.nl2br($content)
			."</blockquote><br/><br/>"
			;
		return $content;
	}
	# send email
	###########################
	public function mailNewComm($emails=null,$content=null,$name=null,$commId=null){
		$plxMotor=plxMotor::getInstance();
		
		if (!empty($plxMotor->plxRecord_arts)) {
			$title   =$plxMotor->plxRecord_arts->f("title");
			$authnum =$plxMotor->plxRecord_arts->f('author');
			$author  =$plxMotor->aUsers[$authnum]['name'];			
			$num 	 =$plxMotor->plxRecord_arts->f('numero');
			$url 	 =$plxMotor->plxRecord_arts->f('url');
		} else {
			global $plxAdmin;
			if(!$_GET['c'] || !preg_match('/^_?([0-9]{4}).(.*)$/',$_GET['c'], $capture)) {
				plxMsg::Error(L_ERR_UNKNOWN_ARTICLE);
				header('Location: index.php');
				exit;
			} else {
				$artId = $capture[1];
			}
			$aFile  =$plxAdmin->plxGlob_arts->query('/^'.$artId.'.(.+).xml$/','','sort',0,1);
			$aArt   =$plxAdmin->parseArticle(PLX_ROOT.$plxAdmin->aConf['racine_articles'].$aFile['0']);
			$authnum=$aArt['author'];
			$author =$plxMotor->aUsers[$aArt['author']];
			$title  =$aArt['title'];
			$num    =$aArt['numero'];
			$url    =$aArt['url'];
		}
		
		
		$content =$this->createContent(
			$num,
			$title,
			$url,
			$content,
			$name
			);

		$subject=$plxMotor->aConf['title'].': '.$this->getLang('L_NEW_COMMENT_ABOUT').' «'.$title.'»';
		$urlad  =$plxMotor->aConf['racine'].'core/admin/comments.php?sel=offline&page=1';
		
		# email to article's author
		if (!empty($_POST['mail'])){
			$comemail   =strip_tags($_POST['mail']);
			$answerlink ='<a href="mailto:'.$comemail.'">'.$this->getLang('L_EMAILANSWER').' &#8631;</a>';
			$name      .=' <'.$comemail.'>';
		}else{
			$answerlink=$comemail='';
		}
		if ($this->getParam('mail_to_author')){
			plxUtils::sendMail(
				$name, 
				$plxMotor->aConf['title'], 
				strip_tags($plxMotor->aUsers[$authnum]["email"]), 
				$subject, 
				str_replace('#DESTINATAIRE',$author,$content).'<hr/><a href="'.$urlad.'">'.$this->getLang('L_MODERATE_PAGE').' &#8605;</a> '.$answerlink, 
				$contentType="html"
			);
		}

		if ($commId=='mod'){
			return;
		}
		# email to users (when moderation is off)
		if (is_string($emails)){ $emails=array($emails);}

		if (empty($emails)&&!empty($this->db[$num])){
			$emails=$this->db[$num];
		}elseif (empty($emails)){
			return false;
		}

		$content.='<hr/><a href="'.$plxMotor->aConf['racine'].$url.'">Article &#8605;</a> - <a href="'.$plxMotor->aConf['racine'].$url.'#'.$commId.'">Comm &#8605;</a> ';
		foreach($emails as $email=>$name){			
			$content_temp=$content.'- <a href="'.$url.'&unsuscribe='.$email.'&a='.$artId.'">'.$this->getLang('L_UNSUSCRIBE').' &#10006;</a>';
			plxUtils::sendMail($name, $plxMotor->aConf['title'], $email, $subject, str_replace('#DESTINATAIRE',$name,$content_temp), $contentType="html");
		}
			
		
		
	}


}
?>